@@ -338,7 +338,8 @@ struct snapraid_disk {
 
 	uint64_t tick; /**< Usage time. */
 	uint64_t progress_tick[PROGRESS_MAX]; /**< Last ticks of progress. */
-	unsigned cached; /**< Number of IO blocks cached. */
+	unsigned cached_blocks; /**< Number of IO blocks cached. */
+	struct snapraid_file* progress_file; /**< File in progress. */
 
 	/**
 	 * First free searching block.
@@ -348,6 +349,7 @@ struct snapraid_disk {
 	block_off_t first_free_block;
 
 	int has_volatile_inodes; /**< If the underline file-system has not persistent inodes. */
+	int has_volatile_hardlinks; /**< If the underline file-system has not syncronized metadata for hardlink (NTFS). */
 	int has_unreliable_physical; /**< If the physical offset of files has duplicates. */
 	int has_different_uuid; /**< If the disk has a different UUID, meaning that it is not the same file-system. */
 	int has_unsupported_uuid; /**< If the disk doesn't report UUID, meaning it's not supported. */
@@ -463,11 +465,11 @@ struct snapraid_parity {
 	char smartctl[PATH_MAX]; /**< Custom command for smartctl. Empty means auto. */
 	block_off_t total_blocks; /**< Number of total blocks. */
 	block_off_t free_blocks; /**< Number of free blocks at the last sync. */
-	int is_excluded; /**< If the parity is excluded by disk filter. */
+	int is_excluded_by_filter; /**< If the parity is excluded by filters. */
 	int skip_access; /**< If at least one of the parity disk is inaccessible and it should be skipped. */
 	uint64_t tick; /**< Usage time. */
 	uint64_t progress_tick[PROGRESS_MAX]; /**< Last cpu ticks of progress. */
-	unsigned cached; /**< Number of IO blocks cached. */
+	unsigned cached_blocks; /**< Number of IO blocks cached. */
 };
 
 /**
