@@ -917,18 +917,20 @@ static int devtree(const char* name, const char* custom, dev_t device, devinfo_t
 
 		while ((dd = readdir(d)) != 0) {
 			if (dd->d_name[0] != '.') {
+				dev_t subdev;
+
 				/* for each slave, expand the full potential tree */
 				pathprint(path, sizeof(path), "/sys/dev/block/%u:%u/slaves/%s/dev", major(device), minor(device), dd->d_name);
 
-				device = devread(path);
-				if (!device) {
+				subdev = devread(path);
+				if (!subdev) {
 					/* LCOV_EXCL_START */
 					closedir(d);
 					return -1;
 					/* LCOV_EXCL_STOP */
 				}
 
-				if (devtree(name, custom, device, parent, list) != 0) {
+				if (devtree(name, custom, subdev, parent, list) != 0) {
 					/* LCOV_EXCL_START */
 					closedir(d);
 					return -1;
@@ -1072,8 +1074,8 @@ static int devscan(tommy_list* list)
 #if HAVE_LINUX_DEVICE
 static int devsmart(dev_t device, const char* name, const char* custom, uint64_t* smart, char* serial, char* vendor, char* model)
 {
-	char cmd[128];
-	char file[128];
+	char cmd[PATH_MAX + 64];
+	char file[PATH_MAX];
 	FILE* f;
 	int ret;
 
@@ -1086,7 +1088,7 @@ static int devsmart(dev_t device, const char* name, const char* custom, uint64_t
 
 	/* if there is a custom command */
 	if (custom[0]) {
-		char option[128];
+		char option[PATH_MAX];
 		snprintf(option, sizeof(option), custom, file);
 		snprintf(cmd, sizeof(cmd), "smartctl -a %s", option);
 	} else {
@@ -1140,8 +1142,8 @@ static int devsmart(dev_t device, const char* name, const char* custom, uint64_t
 #if HAVE_LINUX_DEVICE
 static int devdown(dev_t device, const char* name, const char* custom)
 {
-	char cmd[128];
-	char file[128];
+	char cmd[PATH_MAX + 64];
+	char file[PATH_MAX];
 	FILE* f;
 	int ret;
 
@@ -1154,7 +1156,7 @@ static int devdown(dev_t device, const char* name, const char* custom)
 
 	/* if there is a custom command */
 	if (custom[0]) {
-		char option[128];
+		char option[PATH_MAX];
 		snprintf(option, sizeof(option), custom, file);
 		snprintf(cmd, sizeof(cmd), "smartctl -s standby,now %s", option);
 	} else {
